@@ -59,6 +59,11 @@ def _print_query(res):
     }
     if query_type in keys:
         print_list(content, keys[query_type])
+    elif query_type in ['all', 'all+files']:
+        for elem in content:
+            content_type = elem["content_type"]
+            print(f"# {content_type}:")
+            _print_query((elem, content_type))
     else:
         print_list(content, content[0].keys())
 
