@@ -8,7 +8,9 @@ def print_list(lst, keys):
     t.align = 'l'
 
     for item in lst:
-        values = [item[key] if key in item else "" for key in keys]
+        values = [item[key]
+                  if key in item else ""
+                  for key in keys]
         t.add_row(values)
     print(t.get_string())
 
