@@ -1,4 +1,5 @@
-from datetime import datetime
+from datetime import datetime, timedelta
+
 from dateutil.parser import parse
 
 
@@ -21,6 +22,10 @@ def date_range_in_sec(start, end, duration=None):
     return from_sec, to_sec
 
 
+def duration_to_timedelta(duration):
+    return timedelta(seconds=(duration_to_seconds(duration)))
+
+
 def duration_to_seconds(duration):
     format_error = "Error: duration needs to be in the form of <num><units> where <units> can be: S, M, H, D or W. (ex: 30M, 1H, 3D, 2W)"
     unit_sec = {
@@ -42,4 +47,4 @@ def duration_to_seconds(duration):
 
 
 def format_timestamp(timestamp):
-    return str(datetime.utcfromtimestamp(timestamp / 10**3))
+    return str(datetime.utcfromtimestamp(timestamp / 10 ** 3))
